pub(super) fn verify_claims<T: DeserializeOwned>(
token: &SecretString,
key: &SecretSlice<u8>,
) -> Result<T, AuthenticationError>Expand description
Applies the same JWT policy as verify with a decoded signing key.
pub(super) fn verify_claims<T: DeserializeOwned>(
token: &SecretString,
key: &SecretSlice<u8>,
) -> Result<T, AuthenticationError>Applies the same JWT policy as verify with a decoded signing key.